package com.thomaskuenneth.minichart;

import java.awt.Image;
import java.awt.Toolkit;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.StringTokenizer;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Diese Klasse verwendet die 
 * <a href="http://code.google.com/apis/chart/">Google Chart API</a>, 
 * um ein einfaches Tortendiagramm zu erzeugen.<p>
 * 
 * @author Thomas Knneth
 */
public class GoogleChart {

    public static String createPieChart(boolean is3d, int width, int height, float[] data) {
        StringBuilder sb = new StringBuilder();
        // Basis-URL
        sb.append("http://chart.apis.google.com/chart?");
        // Gre in Pixel
        sb.append("chs=");
        sb.append(width);
        sb.append("x");
        sb.append(height);
        sb.append("&");
        // Chart-Typ
        sb.append(is3d ? "cht=p3" : "cht=p");
        sb.append("&");
        // Chart-Daten
        sb.append("chd=t:");
        for (int i = 0; i < data.length; i++) {
            if (i > 0) {
                sb.append(",");
            }
            sb.append(data[i]);
        }
        return sb.toString();
    }

    public static float[] parseString(String str) {
        StringTokenizer st = new StringTokenizer(str, "\n");
        float[] result = new float[st.countTokens()];
        for (int i = 0; i < result.length; i++) {
            String current = st.nextToken();
            try {
                result[i] = Float.parseFloat(current);
            } catch (NumberFormatException e) {
                result[i] = 0;
            }
        }
        return result;
    }

    public static Image getChartAsImage(String data) {
        Image img = null;
        try {
            URL url = new URL(data);
            img = Toolkit.getDefaultToolkit().createImage(url);
        } catch (MalformedURLException ex) {
            Logger.getLogger(GoogleChart.class.getName()).log(Level.SEVERE, null, ex);
        }
        return img;
    }
}
