package com.thomaskuenneth.minichart;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Image;
import java.util.EventObject;
import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import org.jdesktop.application.Action;
import org.jdesktop.application.Application;
import org.jdesktop.application.Application.ExitListener;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.Task;

public class MiniChart extends SingleFrameApplication implements ExitListener {

    /**
     * Die Menleiste der Anwendung.
     */
    private JMenuBar menuBar;
    private JMenu menuFile,  menuEdit;
    /**
     * In dieses Textfeld werden die Zahlen eingetragen.
     */
    private JTextArea textareaInput;
    /**
     * Das Label enthlt die durch die Google Chart API erzeugte Grafik.
     */
    private JLabel labelChart;

    /**
     * Der obligatorische Einstiegspunkt in das Programm.
     * 
     * @param args Parameter, die ber die Kommandozeile bergeben wurden
     */
    public static void main(String[] args) {
        launch(MiniChart.class, args);
    }

    /**
     * Initialisiert die Anwendung, baut die Oberflche und zeigt sie an.
     */
    @Override
    protected void startup() {
        addExitListener(this);
        buildMenubar();
        show(buildMainView());
    }

    /**
     * Baut die Menleiste.
     */
    private void buildMenubar() {
        // das Datei-Men
        menuFile = new JMenu();
        menuFile.setName("menuFile");
        menuFile.add(new JMenuItem(getAction("quit")));
        // das Bearbeiten-Men
        menuEdit = new JMenu();
        menuEdit.setName("menuEdit");
        menuEdit.add(new JMenuItem(getAction("render")));
        // die Menleiste bauen
        menuBar = new JMenuBar();
        menuBar.add(menuFile);
        menuBar.add(menuEdit);
        getMainView().setMenuBar(menuBar);
    }

    private JComponent buildMainView() {
        JPanel p = new JPanel(new BorderLayout());
        textareaInput = new JTextArea();
        textareaInput.setName("textareaInput");
        JScrollPane scrollpaneInput = new JScrollPane(textareaInput);
        p.add(scrollpaneInput, BorderLayout.WEST);
        labelChart = new JLabel();
        labelChart.setName("labelChart");
        labelChart.setHorizontalAlignment(JLabel.CENTER);
        labelChart.setVerticalAlignment(JLabel.CENTER);
        labelChart.setPreferredSize(new Dimension(400, 300));
        p.add(new JScrollPane(labelChart), BorderLayout.CENTER);
        return p;
    }

    /**
     * Liefert eine Instanz der Klasse <code>Action</code>.
     * 
     * @param action die gesuchte Action
     * @return eine Instanz der Klasse <code>Action</code>
     */
    javax.swing.Action getAction(String action) {
        return getContext().getActionMap().get(action);
    }

    @Action
    public Task render() {
        return new Task<Image, Void>(Application.getInstance()) {

            @Override
            protected Image doInBackground() {
                float[] data = GoogleChart.parseString(textareaInput.getText());
                String url = GoogleChart.createPieChart(true, 400, 300, data);
                System.out.println(url);
                return GoogleChart.getChartAsImage(url);
            }

            @Override
            protected void succeeded(Image result) {
                labelChart.setIcon(new ImageIcon(result));
            }
        };
    }

    ////////////////////////////
    // ExitListener interface //
    ////////////////////////////
    public boolean canExit(EventObject event) {
        String msg = getContext().getResourceMap().getString("confirmQuit");
        if (JOptionPane.showConfirmDialog(getMainFrame(), msg, getMainFrame().getTitle(), JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION) {
            return true;
        }
        return false;
    }

    public void willExit(EventObject event) {
    }
}
